@@ -8,8 +8,7 @@ use ockam_core::vault::{
     AsymmetricVault, Hasher, PublicKey, Secret, SecretAttributes, SecretVault, SymmetricVault,
 };
 use ockam_core::{Error, Result};
-use ockam_vault::SoftwareVault;
-use ockam_vault_sync_core::VaultMutex;
+use ockam_vault::Vault;
 use std::future::Future;
 use tokio::runtime::Runtime;
 use tokio::sync::RwLock;
@@ -21,7 +20,7 @@ pub trait FfiVault: SecretVault + Hasher + SymmetricVault + AsymmetricVault + Se
 impl<D> FfiVault for D where D: SecretVault + Hasher + SymmetricVault + AsymmetricVault + Send {}
 
 lazy_static! {
-    static ref SOFTWARE_VAULTS: RwLock<Vec<VaultMutex<SoftwareVault>>> = RwLock::new(vec![]);
+    static ref SOFTWARE_VAULTS: RwLock<Vec<Vault>> = RwLock::new(vec![]);
     static ref RUNTIME: Arc<Runtime> = Arc::new(Runtime::new().unwrap());
 }
 
@@ -40,7 +39,7 @@ where
     })
 }
 
-async fn get_vault(context: FfiVaultFatPointer) -> Result<VaultMutex<SoftwareVault>> {
+async fn get_vault(context: FfiVaultFatPointer) -> Result<Vault> {
     match context.vault_type() {
         FfiVaultType::Software => {
             let item = SOFTWARE_VAULTS
@@ -62,7 +61,7 @@ pub extern "C" fn ockam_vault_default_init(context: &mut FfiVaultFatPointer) ->
         // TODO: handle logging
         let handle = block_future(async move {
             let mut write_lock = SOFTWARE_VAULTS.write().await;
-            write_lock.push(VaultMutex::create(SoftwareVault::default()));
+            write_lock.push(Vault::default());
             write_lock.len() - 1
         });
 
@@ -88,7 +87,7 @@ pub extern "C" fn ockam_vault_sha256(
         let input = unsafe { core::slice::from_raw_parts(input, input_length as usize) };
 
         let res = block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             v.sha256(input).await
         })?;
 
@@ -109,7 +108,7 @@ pub extern "C" fn ockam_vault_secret_generate(
 ) -> FfiOckamError {
     handle_panics(|| {
         *secret = block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let atts = attributes.try_into()?;
             let ctx = v.secret_generate(atts).await?;
             Ok::<u64, Error>(ctx.index() as u64)
@@ -130,7 +129,7 @@ pub extern "C" fn ockam_vault_secret_import(
     handle_panics(|| {
         check_buffer!(input, input_length);
         *secret = block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let atts = attributes.try_into()?;
 
             let secret_data = unsafe { core::slice::from_raw_parts(input, input_length as usize) };
@@ -154,7 +153,7 @@ pub extern "C" fn ockam_vault_secret_export(
     *output_buffer_length = 0;
     handle_panics(|| {
         block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let key = v.secret_export(&ctx).await?;
             if output_buffer_size < key.as_ref().len() as u32 {
@@ -187,7 +186,7 @@ pub extern "C" fn ockam_vault_secret_publickey_get(
     *output_buffer_length = 0;
     handle_panics(|| {
         block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let key = v.secret_public_key_get(&ctx).await?;
             if output_buffer_size < key.as_ref().len() as u32 {
@@ -217,7 +216,7 @@ pub extern "C" fn ockam_vault_secret_attributes_get(
 ) -> FfiOckamError {
     handle_panics(|| {
         *attributes = block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let atts = v.secret_attributes_get(&ctx).await?;
             Ok::<FfiSecretAttributes, Error>(atts.into())
@@ -233,7 +232,7 @@ pub extern "C" fn ockam_vault_secret_destroy(
     secret: SecretKeyHandle,
 ) -> FfiOckamError {
     match block_future(async move {
-        let mut v = get_vault(context).await?;
+        let v = get_vault(context).await?;
         let ctx = Secret::new(secret as usize);
         v.secret_destroy(ctx).await?;
         Ok::<(), Error>(())
@@ -260,7 +259,7 @@ pub extern "C" fn ockam_vault_ecdh(
             unsafe { core::slice::from_raw_parts(peer_publickey, peer_publickey_length as usize) };
 
         *shared_secret = block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let atts = v.secret_attributes_get(&ctx).await?;
             let pubkey = PublicKey::new(peer_publickey.to_vec(), atts.stype());
@@ -286,7 +285,7 @@ pub extern "C" fn ockam_vault_hkdf_sha256(
         let derived_outputs_count = derived_outputs_count as usize;
 
         block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let salt_ctx = Secret::new(salt as usize);
             let ikm_ctx = if input_key_material.is_null() {
                 None
@@ -362,7 +361,7 @@ pub extern "C" fn ockam_vault_aead_aes_gcm_encrypt(
             unsafe { core::slice::from_raw_parts(plaintext, plaintext_length as usize) };
 
         block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let mut nonce_vec = vec![0; 12 - 2];
             nonce_vec.extend_from_slice(&nonce.to_be_bytes());
@@ -416,7 +415,7 @@ pub extern "C" fn ockam_vault_aead_aes_gcm_decrypt(
         };
 
         block_future(async move {
-            let mut v = get_vault(context).await?;
+            let v = get_vault(context).await?;
             let ctx = Secret::new(secret as usize);
             let mut nonce_vec = vec![0; 12 - 2];
             nonce_vec.extend_from_slice(&nonce.to_be_bytes());
